@@ -1,18 +1,18 @@
-# Copyright (c) 2015-2016, 2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2016 Ceridwen <ceridwenv@gmail.com>
 # Copyright (c) 2017 Roy Wright <roy@wright.org>
 # Copyright (c) 2018 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2019 Antoine Boellinger <aboellinger@hotmail.com>
+# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
+# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
 
 """Astroid hooks for the PyQT library."""
 
-from astroid import MANAGER, register_module_extender
+from astroid import MANAGER, nodes, parse, register_module_extender
 from astroid.builder import AstroidBuilder
-from astroid import nodes
-from astroid import parse
 
 
 def _looks_like_signal(node, signal_name="pyqtSignal"):
