@@ -1,5 +1,5 @@
 # Copyright (c) 2006-2011, 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2014-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 BioGeek <jeroen.vangoey@gmail.com>
 # Copyright (c) 2014 Google, Inc.
 # Copyright (c) 2014 Eevee (Alex Munroe) <amunroe@yelp.com>
@@ -8,9 +8,15 @@
 # Copyright (c) 2017 Iva Miholic <ivamiho@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2019 Raphael Gaschignard <raphael@makeleaps.com>
+# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Raphael Gaschignard <raphael@rtpg.co>
+# Copyright (c) 2020 Anubhav <35621759+anubh-v@users.noreply.github.com>
+# Copyright (c) 2020 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
+# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
 
 """astroid manager: avoid multiple astroid build of a same module when
 possible by providing a class responsible to get astroid representation
@@ -20,11 +26,8 @@ from various source and using a cache of built modules)
 import os
 import zipimport
 
-from astroid import exceptions
+from astroid import exceptions, modutils, transforms
 from astroid.interpreter._import import spec
-from astroid import modutils
-from astroid import transforms
-
 
 ZIP_IMPORT_EXTS = (".zip", ".egg", ".whl")
 
@@ -99,6 +102,13 @@ class AstroidManager:
             "Unable to build an AST for {path}.", path=filepath
         )
 
+    def ast_from_string(self, data, modname="", filepath=None):
+        """ Given some source code as a string, return its corresponding astroid object"""
+        # pylint: disable=import-outside-toplevel; circular import
+        from astroid.builder import AstroidBuilder
+
+        return AstroidBuilder(self).string_build(data, modname, filepath)
+
     def _build_stub_module(self, modname):
         # pylint: disable=import-outside-toplevel; circular import
         from astroid.builder import AstroidBuilder
@@ -124,12 +134,13 @@ class AstroidManager:
 
     def ast_from_module_name(self, modname, context_file=None):
         """given a module name, return the astroid object"""
+        # pylint: disable=no-member
         if modname in self.astroid_cache:
             return self.astroid_cache[modname]
         if modname == "__main__":
             return self._build_stub_module(modname)
-        old_cwd = os.getcwd()
         if context_file:
+            old_cwd = os.getcwd()
             os.chdir(os.path.dirname(context_file))
         try:
             found_spec = self.file_from_module_name(modname, context_file)
@@ -168,6 +179,8 @@ class AstroidManager:
                 return self._build_namespace_module(
                     modname, found_spec.submodule_search_locations
                 )
+            elif found_spec.type == spec.ModuleType.PY_FROZEN:
+                return self._build_stub_module(modname)
 
             if found_spec.location is None:
                 raise exceptions.AstroidImportError(
@@ -183,7 +196,8 @@ class AstroidManager:
                     pass
             raise e
         finally:
-            os.chdir(old_cwd)
+            if context_file:
+                os.chdir(old_cwd)
 
     def zip_import_data(self, filepath):
         if zipimport is None:
@@ -199,7 +213,9 @@ class AstroidManager:
             except ValueError:
                 continue
             try:
-                importer = zipimport.zipimporter(eggpath + ext)
+                importer = zipimport.zipimporter(  # pylint: disable=no-member
+                    eggpath + ext
+                )
                 zmodname = resource.replace(os.path.sep, ".")
                 if importer.is_package(resource):
                     zmodname = zmodname + ".__init__"
@@ -223,11 +239,13 @@ class AstroidManager:
                 value = exceptions.AstroidImportError(
                     "Failed to import module {modname} with error:\n{error}.",
                     modname=modname,
-                    error=ex,
+                    # we remove the traceback here to save on memory usage (since these exceptions are cached)
+                    error=ex.with_traceback(None),
                 )
             self._mod_file_cache[(modname, contextfile)] = value
         if isinstance(value, exceptions.AstroidBuildingError):
-            raise value
+            # we remove the traceback here to save on memory usage (since these exceptions are cached)
+            raise value.with_traceback(None)
         return value
 
     def ast_from_module(self, module, modname=None):
